@extends('voyager::master')

@section('page_title', __('voyager::generic.view').' '.$dataType->getTranslatedAttribute('display_name_singular'))

@section('page_header')
    <h1 class="page-title">
        <i class="{{ $dataType->icon }}"></i> {{ __('voyager::generic.viewing') }} {{ ucfirst($dataType->getTranslatedAttribute('display_name_singular')) }} &nbsp;

        @can('edit', $dataTypeContent)
            <a href="{{ route('voyager.'.$dataType->slug.'.edit', $dataTypeContent->getKey()) }}" class="btn btn-info">
                <span class="glyphicon glyphicon-pencil"></span>&nbsp;
                {{ __('voyager::generic.edit') }}
            </a>
        @endcan
        @can('delete', $dataTypeContent)
            @if($isSoftDeleted)
                <a href="{{ route('voyager.'.$dataType->slug.'.restore', $dataTypeContent->getKey()) }}" title="{{ __('voyager::generic.restore') }}" class="btn btn-default restore" data-id="{{ $dataTypeContent->getKey() }}" id="restore-{{ $dataTypeContent->getKey() }}">
                    <i class="voyager-trash"></i> <span class="hidden-xs hidden-sm">{{ __('voyager::generic.restore') }}</span>
                </a>
            @else
                <a href="javascript:;" title="{{ __('voyager::generic.delete') }}" class="btn btn-danger delete" data-id="{{ $dataTypeContent->getKey() }}" id="delete-{{ $dataTypeContent->getKey() }}">
                    <i class="voyager-trash"></i> <span class="hidden-xs hidden-sm">{{ __('voyager::generic.delete') }}</span>
                </a>
            @endif
        @endcan

        <a href="{{ route('voyager.'.$dataType->slug.'.index') }}" class="btn btn-warning">
            <span class="glyphicon glyphicon-list"></span>&nbsp;
            {{ __('voyager::generic.return_to_list') }}
        </a>
    </h1>
    @include('voyager::multilingual.language-selector')
@stop

@section('content')
    <div class="page-content read container-fluid">
        <!-- BEGIN OVERRIDE
           Show essential infos and plasmid map
         -->
        <div class="row">
            <div class="col-md-3">
               <div class="panel panel-bordered" style="padding-bottom:0px;">
                  <div class="panel-heading" style="border-bottom:0;">
                            <h3 class="darkfont panel-title">Plasmid {{ $dataTypeContent->id }} </h3>
                            <h3 class="darkfont panel-title">Name: {{ $dataTypeContent->name }} </h3>
			    <h3 class="darkfont panel-title">Type: {{ $dataTypeContent->type }} </h3>
                            <h3 class="darkfont panel-title">Selection: {{ $dataTypeContent->bacterial_selection }} </h3>
			    <h3 class="darkfont panel-title">Species: {{ $dataTypeContent->species }} </h3>
                            <h3 class="darkfont panel-title">Markers: {{ $dataTypeContent->marker1 }},{{ $dataTypeContent->marker2 }} </h3>
                  </div>

                  
               </div>
            </div>
            <div class="col-md-9">
                <div class="panel panel-bordered" style="padding-bottom:0px;">
                   <img class="img-responsive" src="{{ $plasmidmap_imgurl }}">
                </div>
            </div>
        </div>

        <!--
           Provide links to media files
        -->
        <div class="row">
           <div class="col-md-12">
               <div class="panel panel-bordered" style="padding-bottom:5px;">
                  <div class="panel-heading" style="border-bottom:0;">
                    <h4> Links to media files (if any): </h4>
                  </div>
                    @php
                      $sf = substr($dataTypeContent->files, 1, -1);
                      $files = explode(",", $sf);
                      $pathroot = getenv('APP_URL')."/storage/";
                    @endphp

                    @foreach($files as $file)
                      @php
                      $filename = substr($file, 1, -1);   
                      $path = $pathroot.$filename;   
                      @endphp
                            <h4 class="panel-title"> <a href="{{ $path }}"> {{$filename}} </a></h4>
                    @endforeach
               </div>
           </div>
        </div>

        <!--
           Display full sequence
        -->
        <div class="row">
           <div class="col-md-12">
               <div class="panel panel-bordered" style="padding-bottom:5px;">
                  <div class="panel-body">
                     <h4 class = "text-center"> Sequence </h4>
                     <textarea readonly class="form-control" rows=8> {{ $dataTypeContent->sequence }} </textarea>
                  </div>
               </div>
           </div>
        </div>


        <!-- END OVERRIDE -->

        <!-- 
          Show all data entries according to BREAD
         -->
        <div class="row">
            <div class="col-md-12">
                <div class="panel panel-bordered" style="padding-bottom:5px;">
                  <div class="panel-heading" style="border-bottom:0;">
                    <h4> Full info: </h4>
                  </div>

                    <!-- form start -->
                    @foreach($dataType->readRows as $row)
                        @php
                        if ($dataTypeContent->{$row->field.'_read'}) {
                            $dataTypeContent->{$row->field} = $dataTypeContent->{$row->field.'_read'};
                        }
                        @endphp
                        <div class="panel-heading text-primary" style="border-bottom:0;">
                            <h3 class="panel-title">{{ $row->getTranslatedAttribute('display_name') }}</h3>
                        </div>

                        <div class="panel-body" style="padding-top:0;">
                            @if (isset($row->details->view))
                                @include($row->details->view, ['row' => $row, 'dataType' => $dataType, 'dataTypeContent' => $dataTypeContent, 'content' => $dataTypeContent->{$row->field}, 'action' => 'read', 'view' => 'read', 'options' => $row->details])
                            @elseif($row->type == "image")
                                <img class="img-responsive"
                                     src="{{ filter_var($dataTypeContent->{$row->field}, FILTER_VALIDATE_URL) ? $dataTypeContent->{$row->field} : Voyager::image($dataTypeContent->{$row->field}) }}">
                            @elseif($row->type == 'multiple_images')
                                @if(json_decode($dataTypeContent->{$row->field}))
                                    @foreach(json_decode($dataTypeContent->{$row->field}) as $file)
                                        <img class="img-responsive"
                                             src="{{ filter_var($file, FILTER_VALIDATE_URL) ? $file : Voyager::image($file) }}">
                                    @endforeach
                                @else
                                    <img class="img-responsive"
                                         src="{{ filter_var($dataTypeContent->{$row->field}, FILTER_VALIDATE_URL) ? $dataTypeContent->{$row->field} : Voyager::image($dataTypeContent->{$row->field}) }}">
                                @endif
                            @elseif($row->type == 'relationship')
                                 @include('voyager::formfields.relationship', ['view' => 'read', 'options' => $row->details])
                            @elseif($row->type == 'select_dropdown' && property_exists($row->details, 'options') &&
                                    !empty($row->details->options->{$dataTypeContent->{$row->field}})
			    )
                                <!-- BEGIN OVERRIDE -->
                                <div class="darkfont">
				<?php echo $row->details->options->{$dataTypeContent->{$row->field}};?>
                                </div>
                                <!-- END OVERRIDE -->

                            @elseif($row->type == 'select_multiple')
                                @if(property_exists($row->details, 'relationship'))

                                    @foreach(json_decode($dataTypeContent->{$row->field}) as $item)
                                        {{ $item->{$row->field}  }}
                                    @endforeach

                                @elseif(property_exists($row->details, 'options'))
                                    @if (!empty(json_decode($dataTypeContent->{$row->field})))
                                        @foreach(json_decode($dataTypeContent->{$row->field}) as $item)
                                            @if (@$row->details->options->{$item})
                                                {{ $row->details->options->{$item} . (!$loop->last ? ', ' : '') }}
                                            @endif
                                        @endforeach
                                    @else
                                        {{ __('voyager::generic.none') }}
                                    @endif
                                @endif
                            @elseif($row->type == 'date' || $row->type == 'timestamp')
			    @if ( property_exists($row->details, 'format') && !is_null($dataTypeContent->{$row->field}) )
                                    <!-- BEGIN OVERRIDE -->
			            <div class="darkfont">
				    {{ \Carbon\Carbon::parse($dataTypeContent->{$row->field})->formatLocalized($row->details->format) }}
				    </div>
                                    <!-- END OVERRIDE -->
				@else
                                    <!-- BEGIN OVERRIDE -->
			            <div class="darkfont">
				    {{ $dataTypeContent->{$row->field} }}
				    </div>
                                    <!-- END OVERRIDE -->
                                @endif
                            @elseif($row->type == 'checkbox')
                                @if(property_exists($row->details, 'on') && property_exists($row->details, 'off'))
                                    @if($dataTypeContent->{$row->field})
                                    <span class="label label-info">{{ $row->details->on }}</span>
                                    @else
                                    <span class="label label-primary">{{ $row->details->off }}</span>
                                    @endif
                                @else
                                {{ $dataTypeContent->{$row->field} }}
                                @endif
                            @elseif($row->type == 'color')
                                <span class="badge badge-lg" style="background-color: {{ $dataTypeContent->{$row->field} }}">{{ $dataTypeContent->{$row->field} }}</span>
                            @elseif($row->type == 'coordinates')
                                @include('voyager::partials.coordinates')
                            @elseif($row->type == 'rich_text_box')
				@include('voyager::multilingual.input-hidden-bread-read')
                                <!-- BEGIN OVERRIDE -->
			        <div class="darkfont">
				{!! $dataTypeContent->{$row->field} !!}
				</div>
                                <!-- END OVERRIDE -->
                            @elseif($row->type == 'file')
                                @if(json_decode($dataTypeContent->{$row->field}))
                                    @foreach(json_decode($dataTypeContent->{$row->field}) as $file)
								<!-- BEGIN OVERRIDE (set download file name) -->
                                        <a href="{{ Storage::disk(config('voyager.storage.disk'))->url($file->download_link) ?: '' }}" download= "{{ $file->original_name ?: '' }}">
                                            {{ $file->original_name ?: '' }}
                                        </a>
								<!-- BEGIN OVERRIDE (set download file name) -->
                                        <br/>
                                    @endforeach
                                @else
                                    <a href="{{ Storage::disk(config('voyager.storage.disk'))->url($row->field) ?: '' }}">
                                        {{ __('voyager::generic.download') }}
                                    </a>
                                @endif
                            @else
				@include('voyager::multilingual.input-hidden-bread-read')
				<!-- BEGIN OVERRIDE -->
				<p class = "darkfont">{{ $dataTypeContent->{$row->field} }}</p>
				<!-- END OVERRIDE -->
                            @endif
                        </div><!-- panel-body -->
                        @if(!$loop->last)
                            <hr style="margin:0;">
                        @endif
                    @endforeach

                </div>
            </div>
        </div>
    </div>



               
               
    {{-- Single delete modal --}}
    <div class="modal modal-danger fade" tabindex="-1" id="delete_modal" role="dialog">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <button type="button" class="close" data-dismiss="modal" aria-label="{{ __('voyager::generic.close') }}"><span aria-hidden="true">&times;</span></button>
                    <h4 class="modal-title"><i class="voyager-trash"></i> {{ __('voyager::generic.delete_question') }} {{ strtolower($dataType->getTranslatedAttribute('display_name_singular')) }}?</h4>
                </div>
                <div class="modal-footer">
                    <form action="{{ route('voyager.'.$dataType->slug.'.index') }}" id="delete_form" method="POST">
                        {{ method_field('DELETE') }}
                        {{ csrf_field() }}
                        <input type="submit" class="btn btn-danger pull-right delete-confirm"
                               value="{{ __('voyager::generic.delete_confirm') }} {{ strtolower($dataType->getTranslatedAttribute('display_name_singular')) }}">
                    </form>
                    <button type="button" class="btn btn-default pull-right" data-dismiss="modal">{{ __('voyager::generic.cancel') }}</button>
                </div>
            </div><!-- /.modal-content -->
        </div><!-- /.modal-dialog -->
    </div><!-- /.modal -->



@stop

@section('javascript')
    @if ($isModelTranslatable)
        <script>
            $(document).ready(function () {
                $('.side-body').multilingual();
            });
        </script>
    @endif
    <script>
        var deleteFormAction;
        $('.delete').on('click', function (e) {
            var form = $('#delete_form')[0];

            if (!deleteFormAction) {
                // Save form action initial value
                deleteFormAction = form.action;
            }

            form.action = deleteFormAction.match(/\/[0-9]+$/)
                ? deleteFormAction.replace(/([0-9]+$)/, $(this).data('id'))
                : deleteFormAction + '/' + $(this).data('id');

            $('#delete_modal').modal('show');
        });

    </script>
@stop

